"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.CtxProvider = exports.Context = void 0;
const stream_1 = require("stream");
const Debug = require("debug");
const statuses = require("statuses");
const parse = require("parseurl");
const qs = require("querystring");
const logger = Debug('acp:server');
class Context {
    constructor(req, res) {
        this.req = req;
        this.res = res;
        this._querycache = {};
        this.responseHeaders = {};
        this.body = null;
        this.urlParsedCache = parse(req);
    }
    get path() {
        return this.urlParsedCache.pathname;
    }
    get headers() {
        return this.req.headers;
    }
    get method() {
        return this.req.method;
    }
    get querystring() {
        if (!this.req)
            return '';
        return (this.urlParsedCache.query || '');
    }
    get search() {
        if (!this.querystring)
            return '';
        return `?${this.querystring}`;
    }
    get(field) {
        const req = this.req;
        switch ((field = field.toLowerCase())) {
            case 'referer':
            case 'referrer':
                return (req.headers.referrer || req.headers.referer || '');
            default:
                return (req.headers[field] || '');
        }
    }
    get query() {
        const str = this.querystring;
        if (Reflect.has(this._querycache, str)) {
            return Reflect.get(this._querycache, str);
        }
        const val = qs.parse(str);
        Reflect.set(this._querycache, str, { value: val });
        return val;
    }
    get statusCode() {
        return this.res.statusCode;
    }
    set statusCode(code) {
        this.res.statusCode = code;
    }
    get statusMessage() {
        return this.res.statusMessage;
    }
    set statusMessage(msg) {
        this.res.statusMessage = msg;
    }
    get writable() {
        if (this.res.writableEnded)
            return false;
        const socket = this.res.socket;
        if (!socket)
            return true;
        return socket.writable;
    }
    set(field, val) {
        try {
            this.res.setHeader(field, val);
        }
        catch (e) {
            logger('Error set headers', field, val);
        }
        return this;
    }
    respond() {
        logger('responding');
        if (!this.writable)
            return;
        const res = this.res;
        const body = this.body;
        const code = this.statusCode;
        if (statuses.empty[code]) {
            this.body = null;
            return res.end();
        }
        if ('HEAD' === this.method) {
            if (!res.headersSent) {
            }
            return res.end();
        }
        if (body instanceof stream_1.Stream) {
            body.pipe(res);
            return;
        }
        res.end(body);
    }
}
exports.Context = Context;
function CtxProvider(request, response) {
    return new Context(request, response);
}
exports.CtxProvider = CtxProvider;
