/// <reference types="node" />
import { IncomingMessage, ClientRequest } from 'http';
import * as FollowRedirects from 'follow-redirects';
import * as Http from 'http';
import { IContext } from '../types';
import { Stream } from 'stream';
export interface IProxyOptions {
    target: string;
    port?: number;
    followRedirects?: boolean;
    changeOrigin?: boolean;
    timeout?: number;
}
export interface IProxyResponse<T = unknown> {
    [x: string]: unknown;
    data: T;
    statusCode: number;
    statusMessage: string;
    headers: Record<string, string>;
    request?: ExtendedClientRequest;
    response?: IncomingMessage;
    toJSON?: () => IProxyResponse<T>;
    message?: string;
}
export declare type ProxyResponsePromise<T = unknown> = Promise<IProxyResponse<T>>;
interface ExtendedClientRequest extends ClientRequest {
    pipes?(ctx: IContext): ExtendedClientRequest;
    toPromise?(): ProxyResponsePromise<unknown>;
}
interface IErrorRespone {
    statusCode: number;
    statusMessage: string;
    headers: Record<string, string>;
}
interface IProxyReponseCtx {
    pipes: (ctx: IContext, osham_headers?: Record<string, string>) => IProxyReponseCtx;
    toPromise: () => Promise<IProxyResponse>;
    proxy: Proxy;
    request: ClientRequest | FollowRedirects.RedirectableRequest<ClientRequest, IncomingMessage>;
    response: IErrorRespone | IncomingMessage;
    message: string;
}
declare class Proxy {
    private options;
    static isSSL: RegExp;
    static upgradeHeader: RegExp;
    static ErrorResponse: IErrorRespone;
    private isSecure;
    private agent;
    private port;
    private target;
    constructor(options: IProxyOptions);
    request(path: string, method: string, headers: Record<string, string>, dataStream?: Stream): Promise<IProxyReponseCtx>;
    private getRequestOptions;
}
export declare function createProxy(options: IProxyOptions): (path: string, method: string, headers: Http.IncomingHttpHeaders, dataStream?: Stream) => Promise<IProxyReponseCtx>;
export {};
