"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Cache = void 0;
const Debug = require("debug");
const mem_store_1 = require("../storage/mem.store");
const redis_store_1 = require("../storage/redis.store");
const logger = Debug('acp:service:cache');
class Cache {
    static isConnected() {
        return this.store.connected;
    }
    static put(key, value, exptime) {
        logger('Caching ->', key);
        return new Promise(resolve => {
            this.store.set(key, JSON.stringify(value), () => {
                if (exptime)
                    this.store.expire(key, exptime);
                logger('Cached ->', key);
                return resolve(value);
            });
        });
    }
    static get(key) {
        if (!Cache.isConnected())
            throw new Error('Unable to connect Cache storage.');
        return new Promise((resolve, reject) => {
            this.store.get(key, (error, buffer) => {
                if (error || !buffer) {
                    logger('failed cache ->', key);
                    return reject(new Error(`Cache not found for key ${key}`));
                }
                logger('From cache ->', key);
                return resolve(JSON.parse(buffer.toString()));
            });
        });
    }
    static purge(key) {
        logger('Invalidating cache ->', key);
        return new Promise(resolve => {
            this.store.del(key, (_, reply) => {
                resolve(reply);
            });
        });
    }
}
exports.Cache = Cache;
Cache.store = getCacheStore();
function getCacheStore() {
    if (process.env.REDIS_HOST && process.env.REDIS_PORT) {
        return redis_store_1.RedisClientProvider();
    }
    logger('Redis properties not defined, using in memory cache. Not advised for production.');
    return new mem_store_1.MemStore(5);
}
