"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.generateKey = void 0;
const crypto_1 = require("crypto");
const hasher = crypto_1.createHash('sha1');
function createHashKey(namespace, path, token) {
    if (!token) {
        return `O:${namespace}:${path}`;
    }
    return `O:${namespace}:${path}:${hasher.update(token).digest('base64')}`;
}
function generateKey(ns, ctx, options) {
    if (!options || (!options.query && !options.headers)) {
        return createHashKey(ns, ctx.path);
    }
    const headers = [];
    if (options.headers) {
        for (const header of options.headers) {
            const value = ctx.get(header);
            if (!value)
                continue;
            headers.push(`${header}:${value}`);
        }
    }
    const queryString = [];
    if (options.query) {
        for (const q of options.query) {
            const value = ctx.query[q];
            if (!value)
                continue;
            queryString.push(`${q}=${value}`);
        }
    }
    const varient = (headers.length ? '-' + headers.join('|') : '') + (queryString.length ? '?' + queryString.join('&') : '');
    return createHashKey(ns, ctx.path, varient);
}
exports.generateKey = generateKey;
