"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.RequestPool = void 0;
const cache_service_1 = require("./cache.service");
const Debug = require("debug");
const events_1 = require("events");
const utils_1 = require("../utils");
const logger = Debug('acp:service:pool');
const TIMEOUT = +process.env.TIMEOUT || 5000;
class RequestPool {
    static has(key) {
        return RequestPool.pool.has(key);
    }
    static add(key) {
        RequestPool.pool.add(key);
        return RequestPool;
    }
    static wait(key) {
        logger(`wating for ${key}`);
        return new Promise(resolve => {
            const timeout = setTimeout(() => {
                RequestPool.pool.delete(key);
                RequestPool.ee.off(key, handler);
                logger(`TIMEOUT ${key}`);
                handler(utils_1.timeOutResponse('RequestPool failed'));
            }, TIMEOUT);
            function handler(data) {
                clearTimeout(timeout);
                resolve(data);
                logger(`respond for ${key}`);
            }
            RequestPool.ee.once(key, handler);
        });
    }
    static async putAndPublish(key, data, expires) {
        logger(`putting and publishing for ${key}`);
        RequestPool.pool.delete(key);
        RequestPool.ee.emit(key, data);
        await cache_service_1.Cache.put(key, data, expires);
        return data;
    }
    static async errorAndPublish(key, data) {
        logger(`error and publishing for ${key}`);
        RequestPool.pool.delete(key);
        RequestPool.ee.emit(key, data);
    }
}
exports.RequestPool = RequestPool;
RequestPool.pool = new Set();
RequestPool.ee = new events_1.EventEmitter().setMaxListeners(Infinity);
