"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.MemStore = void 0;
class MemStore {
    constructor(ttl_sec) {
        this.ttl_sec = ttl_sec;
        this.connected = true;
        this.expired = new Map();
        this.cache = new Map();
    }
    get(key, cb) {
        if (!this.expired.has(key)) {
            return cb(new Error('Not found'), null);
        }
        if (this.expired.get(key) < Date.now()) {
            return cb(new Error('Expired'), null);
        }
        if (this.cache.has(key)) {
            return cb(null, this.cache.get(key));
        }
        return cb(new Error('Not found'), null);
    }
    set(key, value, cb) {
        this.cache.set(key, value);
        this.expired.set(key, Date.now() + this.ttl_sec * 1000);
        cb();
    }
    del(key, cb) {
        this.cache.delete(key);
        this.expired.delete(key);
        cb(null, 1);
    }
    expire(key, ttl_sec) {
        this.expired.set(key, Date.now() + ttl_sec * 1000);
    }
}
exports.MemStore = MemStore;
