"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.errorToData = exports.isNameSpace = exports.timeOutResponse = exports.nextTick = exports.respondWithCtx = void 0;
function respondWithCtx(ctx, osham_headers = {}) {
    return ({ statusCode, headers, data }) => {
        ctx.statusCode = statusCode;
        for (const key in headers) {
            if (!Object.prototype.hasOwnProperty.call(headers, key))
                continue;
            ctx.set(key, String(headers[key]));
        }
        for (const key in osham_headers) {
            if (!Object.prototype.hasOwnProperty.call(osham_headers, key))
                continue;
            ctx.set(key, String(osham_headers[key]));
        }
        ctx.body = data;
        return {
            statusCode,
            headers,
            data,
        };
    };
}
exports.respondWithCtx = respondWithCtx;
function nextTick() {
    return new Promise(resolve => {
        process.nextTick(resolve);
    });
}
exports.nextTick = nextTick;
function timeOutResponse(reason) {
    return {
        statusCode: 408,
        statusMessage: 'Request Timeout',
        headers: {},
        data: reason || 'Request Timeout',
    };
}
exports.timeOutResponse = timeOutResponse;
function isNameSpace(key, options) {
    if (typeof key !== 'string')
        return false;
    if (!options)
        return false;
    if (typeof options !== 'object')
        return false;
    if (!options.expose || !options.target)
        return false;
    return true;
}
exports.isNameSpace = isNameSpace;
function errorToData(error) {
    const out = { statusCode: 503, data: '', headers: {} };
    try {
        const { message, statusCode, data, headers } = error;
        if (message) {
            return { statusCode, data, headers };
        }
        out.data = message;
    }
    catch (e) { }
    return out;
}
exports.errorToData = errorToData;
